@@ -94,14 +94,6 @@ class Account:
 		self._dp = self._account_info['realcash']
 		self._char_slots = self._account_info['chrslot']
 
-	@property
-	def account_info(self):
-		return self._account_info
-
-	@property
-	def database_config(self):
-		return self._database_config
-
 	@property
 	def account_id(self):
 		return self._account_id  # Primary Key; DO NOT set
@@ -119,7 +111,7 @@ class Account:
 		else:
 			# Check for clashes
 			data = utils.get_db_all_hits(
-				self.database_config,
+				self._database_config,
 				f"SELECT * FROM `accounts` WHERE `name` = '{new_name}'"
 			)
 			if not data:
@@ -295,6 +287,43 @@ class Account:
 		new_count = int(amount) + self.char_slots
 		self.char_slots = new_count
 
+	def _get_char_list(self):
+		"""Fetch all rows with the same account ID, from DB
+
+		Returns
+			List, representing all characters in the same account
+			Defaults to False in the event of an error during execution
+
+		Raises:
+			Generic error on failure
+		"""
+		data = utils.get_db_all_hits(
+			self._database_config,
+			f"SELECT * FROM `characters` WHERE `accountid` = {self.account_id}"
+		)
+		return data
+
+	@property
+	def characters(self):
+		"""Fetches the IGN of all characters in the same account
+
+		Returns
+			List, containing character names of all characters
+			in the same account
+			Defaults to False in the event of an error during execution
+
+		Raises:
+			Generic error on failure
+		"""
+		char_data = self._get_char_list()
+		return utils.extract_name(char_data)
+
+	@property
+	def free_char_slots(self):
+		total_slots = self._char_slots
+		used_slots = len(self._get_char_list())  # count the number of chars
+		return total_slots - used_slots
+
 	def is_online(self):
 		"""Checks if the 'loggedin' column is greater than 0
 
@@ -334,6 +363,7 @@ class Account:
 			f"Ban Status: {self.banned}, ",
 			f"Ban Reason: {self.ban_reason}, ",
 			f"Total Character Slots: {self.char_slots}, ",
+			f"Free Character Slots: {self.free_char_slots}, ",
 			f"DP: {self.dp}, ",
 			f"VP: {self.vp}, ",
 			f"NX: {self.nx}, ",
@@ -353,7 +383,7 @@ class Account:
 		Raises:
 			Generic error on failure, handled by utils.get_stat_by_column
 		"""
-		return utils.get_stat_by_column(self.account_info, column)
+		return utils.get_stat_by_column(self._account_info, column)
 
 	def set_stat_by_column(self, column, value):
 		"""Sets a account's attributes by column name in database
